- The sending side now sets the parent_ndx value in each file list.
[rsync/rsync.git] / rsync.h
diff --git a/rsync.h b/rsync.h
index be5831c..1232359 100644 (file)
--- a/rsync.h
+++ b/rsync.h
@@ -5,7 +5,7 @@
  * Copyright (C) 2003-2007 Wayne Davison
  *
  * This program is free software; you can redistribute it and/or modify
- * it under the terms of the GNU General Public License version 2 as
+ * it under the terms of the GNU General Public License version 3 as
  * published by the Free Software Foundation.
  *
  * This program is distributed in the hope that it will be useful,
@@ -14,8 +14,7 @@
  * GNU General Public License for more details.
  *
  * You should have received a copy of the GNU General Public License along
- * with this program; if not, write to the Free Software Foundation, Inc.,
- * 51 Franklin Street - Fifth Floor, Boston, MA 02110-1301, USA.
+ * with this program; if not, visit the http://fsf.org website.
  */
 
 #define False 0
@@ -88,7 +87,7 @@
 /* This is used when working on a new protocol version in CVS, and should
  * be a new non-zero value for each CVS change that affects the protocol.
  * It must ALWAYS be 0 when the protocol goes final! */
-#define SUBPROTOCOL_VERSION 3
+#define SUBPROTOCOL_VERSION 4
 
 /* We refuse to interoperate with versions that are not in this range.
  * Note that we assume we'll work with later versions: the onus is on
@@ -675,9 +674,10 @@ struct file_list {
        struct file_struct **files, **sorted;
        alloc_pool_t file_pool;
        void *pool_boundary;
-       int count, malloced;
-       int low, high; /* 0-relative index values excluding empties */
-       int ndx_start; /* the start offset for inc_recurse mode */
+       int used, malloced;
+       int low, high;  /* 0-relative index values excluding empties */
+       int ndx_start;  /* the start offset for inc_recurse mode */
+       int ndx_end;    /* the end offset for inc_recurse mode */
        int parent_ndx; /* dir_flist index of parent directory */
        int in_progress, to_redo;
 };